const Generator = require('yeoman-generator');
const { EOL } = require('os');

module.exports = class extends Generator {
  deleting() {
    const done = this.async();

    const files = [
      'public/index.html',
      'public/manifest.json',
      'src/App.js',
      'src/App.css',
      'src/App.test.js',
      'src/index.css',
      'src/index.js',
      'src/logo.svg',
      'src/registerServiceWorker.js',
    ];

    files.forEach((filename) => {
      this.fs.delete(this.destinationPath(filename));
    });

    this.fs.commit([], done);
  }

  writing() {
    const pkgConfig = require(this.destinationPath('package.json'));

    pkgConfig.scripts = pkgConfig.scripts || {};

    pkgConfig.scripts['build'] = 'react-app-rewired build';
    delete pkgConfig.scripts.eject;
    pkgConfig.scripts['lint'] = 'eslint src/**/**.js test/**/**.js --quiet';
    pkgConfig.scripts['lint:fix'] = 'eslint src/**/**.js test/**/**.js --fix --quiet';
    pkgConfig.scripts['start'] = 'react-app-rewired start';
    pkgConfig.scripts['test'] = 'nyc mocha';
    pkgConfig.scripts['test:ci'] = 'nyc mocha -R mocha-junit-reporter && nyc report';
    pkgConfig.scripts['test:functional'] = 'nyc mocha test/functional';
    pkgConfig.scripts['test:integration'] = 'nyc mocha test/integration';
    pkgConfig.scripts['test:regression'] = 'nyc mocha test/regression';
    pkgConfig.scripts['test:unit'] = 'nyc mocha test/unit';

    this.fs.writeJSON(
      this.destinationPath('package.json'),
      pkgConfig
    );

    const fileTemplates = [
      '_babelrc',
      '_circleci/config.yml',
      '_editorconfig',
      '_eslintignore',
      '_eslintrc',
      '_npmrc',
      '_nvmrc',
      '_nycrc',
      'config-overrides.js',
      'public/index.html',
      'public/manifest.json',
      'src/App.js',
      'src/Navigation.js',
      'src/Router.js',
      'src/components/DefaultComponent.js',
      'src/constants.js',
      'src/containers/DefaultContainer.js',
      'src/helpers/DateTimeHelpers.js',
      'src/index.js',
      'src/layouts/DefaultLayout.js',
      'src/stores/DefaultStore.js',
      'test/_setup.test.js',
      'test/mocha.opts',
    ];

    this.fs.append(
      this.destinationPath('.gitignore'),
      `.nyc_output${EOL}`
    );

    fileTemplates.forEach((filename) => {
      this.fs.copyTpl(
        this.templatePath(filename),
        this.destinationPath(filename.replace(/^_/, '.')),
        {
          title: pkgConfig.name,
        }
      );
    });
  }

  install() {
    this.npmInstall([
      'axios',
      'mobx',
      'mobx-react',
      'moment',
      'react-router-dom',
    ]);

    this.npmInstall([
      '@babel/core',
      '@babel/preset-env',
      '@babel/preset-react',
      '@babel/register',
      'babel-eslint',
      'chai',
      'chai-enzyme',
      'enzyme',
      'enzyme-adapter-react-16',
      'eslint',
      'mocha',
      'mocha-junit-reporter',
      'nyc',
      'react-app-rewire-mobx',
      'react-app-rewired',
    ], { 'save-dev': true });
  }
};

