const Generator = require('yeoman-generator');
const { execSync } = require('child_process');
const { EOL } = require('os');

module.exports = class extends Generator {
  writing() {
    const pkgConfig = require(this.destinationPath('package.json'));

    pkgConfig.scripts = pkgConfig.scripts || {};

    pkgConfig.scripts['css:build'] = 'node-sass-chokidar --include-path ./node_modules ./src/scss -o ./src/scss';
    pkgConfig.scripts['css:watch'] = 'npm run build-css && node-sass-chokidar --include-path ./node_modules ./src/scss -o ./src/scss --watch --recursive';

    this.fs.writeJSON(
      this.destinationPath('package.json'),
      pkgConfig
    );

    const fileTemplates = [
      'src/Navigation.js',
      'src/containers/DefaultContainer.js',
      'src/index.js',
      'src/layouts/DefaultLayout.js',
      'src/polyfills.js',
      'src/scss/_custom.scss',
      'src/scss/_ie-fix.scss',
      'src/scss/_variables.scss',
      'src/scss/styles.scss',
    ];

    fileTemplates.forEach((filename) => {
      this.fs.copyTpl(
        this.templatePath(filename),
        this.destinationPath(filename.replace(/^_/, '.')),
        {
          title: pkgConfig.name,
          year: new Date().getFullYear(),
        }
      );
    });
  }

  install() {
    this.npmInstall([
      '@coreui/coreui',
      '@coreui/coreui-plugin-chartjs-custom-tooltips',
      '@coreui/icons',
      '@coreui/react',
      '@fortawesome/fontawesome-free',
      '@fortawesome/fontawesome-svg-core',
      '@fortawesome/free-solid-svg-icons',
      '@fortawesome/react-fontawesome',
      'bootstrap',
      'chart.js',
      'classnames',
      'core-js',
      'flag-icon-css',
      'react-chartjs-2',
      'reactstrap',
      'simple-line-icons',
    ]);

    this.npmInstall([
      'node-sass-chokidar',
    ], { 'save-dev': true });
  }

  end() {
    execSync('npm run css:build');
  }
};

