import React, { Component } from 'react';
import { FontAwesomeIcon as Icon } from '@fortawesome/react-fontawesome'
import { inject, observer } from 'mobx-react';

import {
  faCalendarAlt,
  faSync,
} from '@fortawesome/free-solid-svg-icons';

import {
  Button,
  Card,
  CardBody,
  CardHeader,
  FormGroup,
  Input,
  Table,
} from 'reactstrap';

import DefaultComponent from './../components/DefaultComponent';

@inject('defaultStore')
@observer
class DefaultContainer extends Component {
  async componentWillMount() {
    await this.props.defaultStore.loadEvents();
  }

  render() {
    const {
      filter,
      filteredEvents,
      handleFilter,
      loadEvents,
    } = this.props.defaultStore;

    return (
      <div className='animated fadeIn'>
        <Card>
          <CardHeader>
            <Icon icon={faCalendarAlt} className='mr-2' />
            Events
            <div className='card-header-actions'>
              <Button
                color='primary'
                onClick={loadEvents}
                size='sm'
                className='card-header-action text-white'
              >
                <Icon icon={faSync} className='mr-2' />
                Refresh
              </Button>
            </div>
          </CardHeader>
          <CardBody>
            <FormGroup>
              <Input
                className='form-control'
                placeholder='Filter'
                type='text'
                value={filter}
                onChange={handleFilter}
              />
            </FormGroup>
            <Table responsive className='table-outline'>
              <thead className='thead-light'>
                <tr>
                  <th>Event</th>
                  <th>Author</th>
                  <th>Repository</th>
                  <th>Time</th>
                </tr>
              </thead>
              <tbody>
                {filteredEvents.map((event, index) => <DefaultComponent event={event} key={index} />)}
              </tbody>
            </Table>
          </CardBody>
        </Card>
      </div>
    );
  }
}

export default DefaultContainer;

